@@ -5,7 +5,7 @@ use IO::Socket;
 use Carp;
 use vars qw($VERSION $DEBUG);
 use strict;
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use constant COMMAND_SLEEP          => "\x00";
 use constant COMMAND_QUIT           => "\x01";
@@ -24,7 +24,7 @@ use constant COMMAND_DEBUG          => "\x0D";
 use constant COMMAND_PING           => "\x0E";
 use constant COMMAND_TIME           => "\x0F";
 use constant COMMAND_DELAYED_INSERT => "\x10";
-use constant COMMAND_CHANGE_USRE    => "\x11";
+use constant COMMAND_CHANGE_USER    => "\x11";
 use constant COMMAND_BINLOG_DUMP    => "\x12";
 use constant COMMAND_TABLE_DUMP     => "\x13";
 use constant COMMAND_CONNECT_OUT    => "\x14";
@@ -34,8 +34,7 @@ use constant BUFFER_LENGTH       => 1460;
 use constant DEFAULT_UNIX_SOCKET => '/tmp/mysql.sock';
 
 
-sub new
-{
+sub new {
 	my $class = shift;
 	my %args = @_;
 
@@ -59,8 +58,7 @@ sub new
 }
 
 
-sub query
-{
+sub query {
 	my $self = shift;
 	my $sql = join '', @_;
 	my $mysql = $self->{socket};
@@ -69,8 +67,7 @@ sub query
 }
 
 
-sub create_database
-{
+sub create_database {
 	my $self = shift;
 	my $db_name = shift;
 	my $mysql = $self->{socket};
@@ -79,8 +76,7 @@ sub create_database
 }
 
 
-sub drop_database
-{
+sub drop_database {
 	my $self = shift;
 	my $db_name = shift;
 	my $mysql = $self->{socket};
@@ -89,8 +85,7 @@ sub drop_database
 }
 
 
-sub close
-{
+sub close {
 	my $self = shift;
 	my $mysql = $self->{socket};
 	return unless $mysql->can('send');
@@ -103,22 +98,19 @@ sub close
 }
 
 
-sub get_affected_rows_length
-{
+sub get_affected_rows_length {
 	my $self = shift;
 	$self->{affected_rows_length};
 }
 
 
-sub get_insert_id
-{
+sub get_insert_id {
 	my $self = shift;
 	$self->{insert_id};
 }
 
 
-sub create_record_iterator
-{
+sub create_record_iterator {
 	my $self = shift;
 	return undef unless $self->has_selected_record;
 
@@ -131,44 +123,38 @@ sub create_record_iterator
 }
 
 
-sub has_selected_record
-{
+sub has_selected_record {
 	my $self = shift;
 	$self->{selected_record} ? 1 : undef;
 }
 
 
-sub is_error
-{
+sub is_error {
 	my $self = shift;
 	$self->{error_code} ? 1 : undef;
 }
 
 
-sub get_error_code
-{
+sub get_error_code {
 	my $self = shift;
 	$self->{error_code};
 }
 
 
-sub get_error_message
-{
+sub get_error_message {
 	my $self = shift;
 	$self->{server_message};
 }
 
 
-sub debug
-{
+sub debug {
 	my $class = shift;
 	$DEBUG = shift if @_;
 	$DEBUG;
 }
 
 
-sub _connect
-{
+sub _connect {
 	my $self = shift;
 
 	my $mysql;
@@ -183,7 +169,7 @@ sub _connect
 		) or croak "Couldn't connect to $self->{hostname}:$self->{port}/tcp: $@";
 	}
 	else {
-		printf "Use UNIX Socket: %s\n", if $self->debug;
+		printf "Use UNIX Socket: %s\n", $self->{unixsocket} if $self->debug;
 		$mysql = IO::Socket::UNIX->new(
 			Type => SOCK_STREAM,
 			Peer => $self->{unixsocket},
@@ -194,8 +180,7 @@ sub _connect
 }
 
 
-sub _get_server_information
-{
+sub _get_server_information {
 	my $self = shift;
 	my $mysql = $self->{socket};
 
@@ -227,8 +212,7 @@ sub _get_server_information
 }
 
 
-sub _request_authentication
-{
+sub _request_authentication {
 	my $self = shift;
 	my $mysql = $self->{socket};
 	$self->_send_login_message();
@@ -247,8 +231,7 @@ sub _request_authentication
 }
 
 
-sub _send_login_message
-{
+sub _send_login_message {
 	my $self = shift;
 	my $mysql = $self->{socket};
 
@@ -265,8 +248,7 @@ sub _send_login_message
 
 
 
-sub _execute_command
-{
+sub _execute_command {
 	my $self = shift;
 	my $command = shift;
 	my $sql = shift;
@@ -297,8 +279,7 @@ sub _execute_command
 }
 
 
-sub _initialize
-{
+sub _initialize {
 	my $self = shift;
 	$self->_connect;
 	$self->_get_server_information;
@@ -306,8 +287,7 @@ sub _initialize
 }
 
 
-sub _set_error_by_packet
-{
+sub _set_error_by_packet {
 	my $self = shift;
 	my $packet = shift;
 
@@ -318,8 +298,7 @@ sub _set_error_by_packet
 }
 
 
-sub _get_record_by_server
-{
+sub _get_record_by_server {
 	my $self = shift;
 	my $packet = shift;
 	my $mysql = $self->{socket};
@@ -335,8 +314,7 @@ sub _get_record_by_server
 }
 
 
-sub _get_affected_rows_information_by_packet
-{
+sub _get_affected_rows_information_by_packet {
 	my $self = shift;
 	my $packet = shift;
 
@@ -347,8 +325,7 @@ sub _get_affected_rows_information_by_packet
 }
 
 
-sub _is_error
-{
+sub _is_error {
 	my $self = shift;
 	my $packet = shift;
 	return 1 if length $packet < 4;
@@ -356,8 +333,7 @@ sub _is_error
 }
 
 
-sub _is_select_query_result
-{
+sub _is_select_query_result {
 	my $self = shift;
 	my $packet = shift;
 	return undef if $self->_is_error($packet);
@@ -365,8 +341,7 @@ sub _is_select_query_result
 }
 
 
-sub _is_update_query_result
-{
+sub _is_update_query_result {
 	my $self = shift;
 	my $packet = shift;
 	return undef if $self->_is_error($packet);
@@ -374,32 +349,28 @@ sub _is_update_query_result
 }
 
 
-sub _get_result_length
-{
+sub _get_result_length {
 	my $self = shift;
 	my $packet = shift;
 	ord(substr $packet, 0, 1)
 }
 
 
-sub _get_column_length
-{
+sub _get_column_length {
 	my $self = shift;
 	my $packet = shift;
 	ord(substr $packet, 4);
 }
 
 
-sub _get_affected_rows_length
-{
+sub _get_affected_rows_length {
 	my $self = shift;
 	my $packet = shift;
 	ord(substr $packet, 5, 1);
 }
 
 
-sub _get_insert_id
-{
+sub _get_insert_id {
 	my $self = shift;
 	my $packet = shift;
 	return ord(substr $packet, 6, 1) if ord(substr $packet, 6, 1) != 0xfc;
@@ -407,8 +378,7 @@ sub _get_insert_id
 }
 
 
-sub _get_server_message
-{
+sub _get_server_message {
 	my $self = shift;
 	my $packet = shift;
 	return '' if length $packet < 7;
@@ -416,8 +386,7 @@ sub _get_server_message
 }
 
 
-sub _get_error_code
-{
+sub _get_error_code {
 	my $self = shift;
 	my $packet = shift;
 	$self->_is_error($packet)
@@ -426,8 +395,7 @@ sub _get_error_code
 }
 
 
-sub _reset_status
-{
+sub _reset_status {
 	my $self = shift;
 	$self->{insert_id}       = 0;
 	$self->{server_message}  = '';
@@ -436,15 +404,13 @@ sub _reset_status
 }
 
 
-sub _has_next_packet
-{
+sub _has_next_packet {
 	my $self = shift;
 	substr($_[0], -1) ne "\xfe";
 }
 
 
-sub _dump_packet
-{
+sub _dump_packet {
 	my $self = shift;
 	my $packet = shift;
 
@@ -463,8 +429,17 @@ sub _dump_packet
 package Net::MySQL::RecordIterator;
 use strict;
 
-sub new
-{
+use constant NULL_COLUMN           => 251;
+use constant UNSIGNED_CHAR_COLUMN  => 251;
+use constant UNSIGNED_SHORT_COLUMN => 252;
+use constant UNSIGNED_LONG_COLUMN  => 253;
+use constant UNSIGNED_CHAR_LENGTH     => 1;
+use constant UNSIGNED_SHORT_LENGTH    => 2;
+use constant UNSIGNED_LONG_LENGTH     => 4;
+use constant UNSIGNED_QUAD_LENGTH => 8;
+
+
+sub new {
 	my $class = shift;
 	my $packet = shift;
 	bless {
@@ -475,16 +450,14 @@ sub new
 }
 
 
-sub parse
-{
+sub parse {
 	my $self = shift;
 	$self->_get_column_length;
 	$self->_get_column_name;
 }
 
 
-sub each
-{
+sub each {
 	my $self = shift;
 	my @result;
 	return undef if $self->is_end_of_packet;
@@ -497,29 +470,25 @@ sub each
 }
 
 
-sub is_end_of_packet
-{
+sub is_end_of_packet {
 	my $self = shift;
 	length $self->{packet} <= $self->{position} + 1;
 }
 
 
-sub get_field_length
-{
+sub get_field_length {
 	my $self = shift;
 	$self->{column_length};
 }
 
 
-sub get_field_names
-{
+sub get_field_names {
 	my $self = shift;
 	map { $_->{column} } @{$self->{column}};
 }
 
 
-sub _get_column_length
-{
+sub _get_column_length {
 	my $self = shift;
 	$self->{position} += 4;
 	$self->{column_length} = ord substr $self->{packet}, $self->{position}, 1;
@@ -529,8 +498,7 @@ sub _get_column_length
 }
 
 
-sub _get_column_name
-{
+sub _get_column_name {
 	my $self = shift;
 	for my $i (1.. $self->{column_length}) {
 		push @{$self->{column}}, {
@@ -547,14 +515,11 @@ sub _get_column_name
 }
 
 
-sub _get_string_and_seek_position
-{
+sub _get_string_and_seek_position {
 	my $self = shift;
 
-	my $length = ord substr $self->{packet}, $self->{position}, 1;
-	$self->{position} += 1;
-	use constant NULL_COLUMN => 251;
-	return undef if $length == NULL_COLUMN;
+	my $length = $self->_get_field_length();
+	return undef unless defined $length;
 
 	my $string = substr $self->{packet}, $self->{position}, $length;
 	$self->{position} += $length;
@@ -562,11 +527,54 @@ sub _get_string_and_seek_position
 }
 
 
+sub _get_field_length {
+	my $self = shift;
+
+	my $head = ord substr(
+		$self->{packet},
+		$self->{position},
+		UNSIGNED_CHAR_LENGTH
+	);
+	$self->{position} += UNSIGNED_CHAR_LENGTH;
+
+	return undef if $head == NULL_COLUMN;
+	if ($head < UNSIGNED_CHAR_COLUMN) {
+		return $head;
+	}
+	elsif ($head == UNSIGNED_SHORT_COLUMN) {
+		my $length = unpack 'v', substr(
+			$self->{packet},
+			$self->{position},
+			UNSIGNED_SHORT_LENGTH
+		);
+		$self->{position} += UNSIGNED_SHORT_LENGTH;
+		return $length;
+	}
+	elsif ($head == UNSIGNED_LONG_COLUMN) {
+		my $length = unpack 'V', substr(
+			$self->{packet},
+			$self->{position},
+			UNSIGNED_LONG_LENGTH
+		);
+		$self->{position} += UNSIGNED_LONG_LENGTH;
+		return $length;
+	}
+	else {
+		my $length = unpack 'Q', substr(
+			$self->{packet},
+			$self->{position},
+			UNSIGNED_QUAD_LENGTH
+		);
+		$self->{position} += UNSIGNED_QUAD_LENGTH;
+		return $length;
+	}
+}
+
+
 package Net::MySQL::Password;
 use strict;
 
-sub scramble
-{
+sub scramble {
 	my $class = shift;
 	my $password = shift;
 	my $hash_seed = shift;
@@ -617,8 +625,7 @@ sub scramble
 }
 
 
-sub _get_hash
-{
+sub _get_hash {
 	my $password = shift;
 
 	my $nr = 1345345333;
@@ -641,8 +648,7 @@ sub _get_hash
 }
 
 
-sub _and_by_char
-{
+sub _and_by_char {
 	my $source = shift;
 	my $mask   = shift;
 
@@ -650,8 +656,7 @@ sub _and_by_char
 }
 
 
-sub _and_by_long
-{
+sub _and_by_long {
 	my $source = shift;
 	my $mask = shift || 0xFFFFFFFF;
 
@@ -659,8 +664,7 @@ sub _and_by_long
 }
 
 
-sub _xor_by_long
-{
+sub _xor_by_long {
 	my $source = shift;
 	my $mask = shift || 0;
 
@@ -668,8 +672,7 @@ sub _xor_by_long
 }
 
 
-sub _cut_off_to_long
-{
+sub _cut_off_to_long {
 	my $source = shift;
 
 	if ($] >= 5.006) {
@@ -862,7 +865,7 @@ TRUE will be returned if it has a reference result by SELECT.
 
 return the number of column.
 
-=item get_fiend_names()
+=item get_field_names()
 
 return column names by ARRAY.
 
